@@ -12,7 +12,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Objind;
 
-our $VERSION = '2.019';
+our $VERSION = '2.020_01'; # VERSION
 
 =head1 NAME
 
@@ -58,15 +58,14 @@ Holds a direct reference to the next free object in the free list.
 =cut
 
 use strict;
-use vars qw(@inst %inst $uidc);
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
 
-# protected keys during emptying and copying, etc.
-
-@inst = qw(parent objnum objgen isfree nextfree uid realised);
-map {$inst{" $_"} = 1} @inst;
+use vars qw($uidc @inst %inst);
 $uidc = "pdfuid000";
 
+# protected keys during emptying and copying, etc.
+@inst = qw(parent objnum objgen isfree nextfree uid realised);
+$inst{" $_"} = 1 for @inst;
 
 =head2 PDF::API2::Basic::PDF::Objind->new()
 
@@ -74,12 +73,10 @@ Creates a new indirect object
 
 =cut
 
-sub new
-{
+sub new {
     my ($class) = @_;
-    my ($self) = {};
 
-    bless $self, ref $class || $class;
+    bless {}, ref $class || $class;
 }
 
 =head2 uid
@@ -88,110 +85,64 @@ Returns a Unique id for this object, creating one if it didn't have one before
 
 =cut
 
-sub uid
-{ $_[0]->{' uid'} || ($_[0]->{' uid'} = $uidc++); }
+sub uid {
+    $_[0]->{' uid'} || ($_[0]->{' uid'} = $uidc++);
+}
 
 =head2 $r->release
 
-Releases ALL of the memory used by this indirect object, and all of its
-component/child objects.  This method is called automatically by
-'C<PDF::API2::Basic::PDF::File-E<gt>release>' (so you don't have to call it yourself).
+Releases ALL of the memory used by this indirect object, and all of
+its component/child objects.  This method is called automatically by
+'C<PDF::API2::Basic::PDF::File-E<gt>release>' (so you don't have to
+call it yourself).
 
-B<NOTE>, that it is important that this method get called at some point prior
-to the actual destruction of the object.  Internally, PDF files have an
-enormous amount of cross-references and this causes circular references within
-our own internal data structures.  Calling 'C<release()>' forces these circular
-references to be cleaned up and the entire internal data structure purged.
-
-B<Developer note:> As part of the brute-force cleanup done here, this method
-will throw a warning message whenever unexpected key values are found within
-the C<PDF::API2::Basic::PDF::Objind> object.  This is done to help ensure that unexpected
-and unfreed values are brought to your attention, so you can bug us to keep the
-module updated properly; otherwise the potential for memory leaks due to
-dangling circular references will exist.
+B<Note:> it is important that this method get called at some point
+prior to the actual destruction of the object.  Internally, PDF files
+have an enormous amount of cross-references and this causes circular
+references within our own internal data structures.  Calling
+'C<release()>' forces these circular references to be cleaned up and
+the entire internal data structure purged.
 
 =cut
 
-sub __release
-{
-    my ($self, $force) = @_;
-    my (@tofree);
-
-    return($self) unless(ref $self);
-# delete stuff that we know we can, here
-
-    if ($force)
-    {
-        foreach my $key (keys %{$self})
-        {
-            push(@tofree,$self->{$key});
-            $self->{$key}=undef;
-            delete($self->{$key});
-        }
-    }
-    else
-    {  @tofree = map { delete $self->{$_} } keys %{$self}; }
-
-    while (my $item = shift @tofree)
-    {
-        my $ref = ref($item);
-        if (UNIVERSAL::can($item, 'release'))
-        { $item->release($force); }
-        elsif ($ref eq 'ARRAY')
-        { push( @tofree, @{$item} ); }
-        elsif (UNIVERSAL::isa($ref, 'HASH'))
-        { release($item, $force); }
-    }
-
-# check that everything has gone - it better had!
-    foreach my $key (keys %{$self})
-    {
-        # warn ref($self) . " still has '$key' key left after release.\n";
-        $self->{$key}=undef;
-        delete($self->{$key});
-    }
-}
-
-sub release 
-{
+# Maintainer's Question: Couldn't this be handled by a DESTROY method
+# instead of requiring an explicit call to release()?
+sub release {
     my ($self) = @_;
 
     my @tofree = values %$self;
     %$self = ();
 
-    while(my $item = shift @tofree) 
-    {
-        my $ref = ref($item) || next; # common case: value is not reference
-        if(UNIVERSAL::can($item, 'release')) 
-        {
+    while (my $item = shift @tofree) {
+        # common case: value is not reference
+        my $ref = ref($item) || next;
+
+        if (UNIVERSAL::can($item, 'release')) {
             $item->release();
         } 
-        elsif($ref eq 'ARRAY') 
-        {
+        elsif ($ref eq 'ARRAY') {
             push @tofree, @$item;
         } 
-        elsif(UNIVERSAL::isa($ref, 'HASH')) 
-        {
+        elsif (UNIVERSAL::isa($ref, 'HASH')) {
             release($item);
         }
     }
-    
-} 
+}
 
 =head2 $r->val
 
-Returns the val of this object or reads the object and then returns its value.
+Returns the value of this object or reads the object and then returns
+its value.
 
-Note that all direct subclasses *must* make their own versions of this subroutine
-otherwise we could be in for a very deep loop!
+Note that all direct subclasses *must* make their own versions of this
+subroutine otherwise we could be in for a very deep loop!
 
 =cut
 
-sub val
-{
+sub val {
     my ($self) = @_;
 
-    $self->{' parent'}->read_obj(@_)->val unless ($self->{' realised'});
+    $self->{' parent'}->read_obj(@_)->val unless $self->{' realised'};
 }
 
 =head2 $r->realise
@@ -200,8 +151,9 @@ Makes sure that the object is fully read in, etc.
 
 =cut
 
-sub realise
-{ $_[0]->{' realised'} ? $_[0] : $_[0]->{' parent'}->read_obj(@_); }
+sub realise {
+    $_[0]->{' realised'} ? $_[0] : $_[0]->{' parent'}->read_obj(@_);
+}
 
 =head2 $r->outobjdeep($fh, $pdf)
 
@@ -210,11 +162,10 @@ This also means that all direct subclasses must subclass this method or loop for
 
 =cut
 
-sub outobjdeep
-{
+sub outobjdeep {
     my ($self, $fh, $pdf, %opts) = @_;
 
-    $self->{' parent'}->read_obj($self)->outobjdeep($fh, $pdf,%opts) unless ($self->{' realised'});
+    $self->{' parent'}->read_obj($self)->outobjdeep($fh, $pdf, %opts) unless $self->{' realised'};
 }
 
 =head2 $r->outobj($fh)
@@ -224,14 +175,15 @@ outobjdeep to output the contents of the object at this point.
 
 =cut
 
-sub outobj
-{
+sub outobj {
     my ($self, $fh, $pdf, %opts) = @_;
 
-    if (defined $pdf->{' objects'}{$self->uid})
-    { $fh->printf("%d %d R", @{$pdf->{' objects'}{$self->uid}}[0..1]); }
-    else
-    { $self->outobjdeep($fh, $pdf, %opts); }
+    if (defined $pdf->{' objects'}{$self->uid}) {
+        $fh->printf("%d %d R", @{$pdf->{' objects'}{$self->uid}}[0..1]);
+    }
+    else {
+        $self->outobjdeep($fh, $pdf, %opts);
+    }
 }
 
 =head2 $r->elementsof
@@ -241,14 +193,15 @@ something more useful if an array.
 
 =cut
 
-sub elementsof
-{
+sub elementsof {
     my ($self) = @_;
 
-    if ($self->{' realised'})
-    { return ($self); }
-    else
-    { return $self->{' parent'}->read_obj($self)->elementsof; }
+    if ($self->{' realised'}) {
+        return $self;
+    }
+    else {
+        return $self->{' parent'}->read_obj($self)->elementsof;
+    }
 }
 
 
@@ -260,14 +213,14 @@ other than object number and generation.
 
 =cut
 
-sub empty
-{
+sub empty {
     my ($self) = @_;
-    my ($k);
 
-    for $k (keys %$self)
-    { undef $self->{$k} unless $inst{$k}; }
-    $self;
+    for my $k (keys %$self) {
+        undef $self->{$k} unless $inst{$k};
+    }
+
+    return $self;
 }
 
 
@@ -280,13 +233,12 @@ place-holder
 
 =cut
 
-sub merge
-{
+sub merge {
     my ($self, $other) = @_;
-    my ($k);
 
-    for $k (keys %$other)
-    { $self->{$k} = $other->{$k} unless $inst{$k}; }
+    for my $k (keys %$other) {
+        $self->{$k} = $other->{$k} unless $inst{$k};
+    }
     $self->{' realised'} = 1;
     bless $self, ref($other);
 }
@@ -300,8 +252,9 @@ concerned that the object is an object in.
 
 =cut
 
-sub is_obj
-{ defined $_[1]->{' objects'}{$_[0]->uid}; }
+sub is_obj {
+    return defined $_[1]->{' objects'}{$_[0]->uid};
+}
 
 
 =head2 $r->copy($pdf, $res)
@@ -320,26 +273,24 @@ in $res.
 
 =cut
 
-sub copy
-{
+sub copy {
     my ($self, $pdf, $res) = @_;
-    my ($k);
 
-    unless (defined $res)
-    {
+    unless (defined $res) {
         $res = {};
         bless $res, ref($self);
     }
-    foreach $k (keys %$self)
-    {
+    foreach my $k (keys %$self) {
         next if $inst{$k};
         next if defined $res->{$k};
-        if (UNIVERSAL::can($self->{$k}, "is_obj") && !$self->{$k}->is_obj($pdf))
-        { $res->{$k} = $self->{$k}->copy($pdf); }
-        else
-        { $res->{$k} = $self->{$k}; }
+        if (UNIVERSAL::can($self->{$k}, "is_obj") && !$self->{$k}->is_obj($pdf)) {
+            $res->{$k} = $self->{$k}->copy($pdf);
+        }
+        else {
+            $res->{$k} = $self->{$k};
+        }
     }
-    $res;
+    return $res;
 }
 
 1;
