@@ -12,7 +12,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Utils;
 
-our $VERSION = '2.018';
+our $VERSION = '2.020_01'; # VERSION
 
 =head1 NAME
 
@@ -40,9 +40,8 @@ use PDF::API2::Basic::PDF::Literal;
 use Exporter;
 use vars qw(@EXPORT @ISA);
 @ISA = qw(Exporter);
-@EXPORT = qw(PDFBool PDFArray PDFDict PDFLiteral PDFName PDFNull
-             PDFNum PDFStr PDFStrHex PDFUtf asPDFBool asPDFName
-             asPDFNum asPDFStr);
+@EXPORT = qw(PDFBool PDFArray PDFDict PDFName PDFNull
+             PDFNum PDFStr PDFStrHex PDFUtf);
 
 =head2 PDFBool
 
@@ -138,14 +137,4 @@ sub PDFUtf {
     return $string;
 }
 
-=head2 PDFLiteral
-
-Creates a pdf-literal via PDF::API2::Basic::PDF::Literal->new
-
-=cut
-
-sub PDFLiteral {
-    return PDF::API2::Basic::PDF::Literal->new(@_);
-}
-
 1;
