@@ -1,6 +1,6 @@
 package PDF::API2::Resource::ColorSpace::Indexed;
 
-our $VERSION = '2.019';
+our $VERSION = '2.020_01'; # VERSION
 
 use base 'PDF::API2::Resource::ColorSpace';
 
@@ -23,15 +23,6 @@ sub new {
     return($self);
 }
 
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-    $self->{' api'}=$api;
-
-    return($obj);
-}
-
 sub enumColors {
     my $self=shift @_;
     my %col=();
